@@ -18,7 +18,13 @@ DispersionCurve = namedtuple(
 
 class PhaseDispersion(BaseDispersion):
     def __init__(
-        self, thickness, velocity_p, velocity_s, density, algorithm="dunkin", dc=0.005,
+        self,
+        thickness,
+        velocity_p,
+        velocity_s,
+        density,
+        algorithm="dunkin",
+        dc=0.005,
     ):
         """
         Phase velocity dispersion class.
@@ -58,7 +64,7 @@ class PhaseDispersion(BaseDispersion):
 
         Returns
         -------
-        namedtuple
+        :class:`disba.DispersionCurve`
             Dispersion curve as a namedtuple (period, velocity, mode, wave, type).
 
         Note
@@ -141,7 +147,7 @@ class GroupDispersion(BaseDispersion):
 
         Returns
         -------
-        namedtuple
+        :class:`disba.DispersionCurve`
             Dispersion curve as a namedtuple (period, velocity, mode, wave, type).
 
         Note
