@@ -10,7 +10,7 @@ def test_ellipticity(mode, eref):
     velocity_model = helpers.velocity_model(5)
     t = numpy.logspace(0.0, 1.0, 20)
 
-    ell = disba.Ellipticity(*velocity_model)
+    ell = disba.Ellipticity(*velocity_model, algorithm="dunkin")
     rel = ell(t, mode=mode)
 
     assert numpy.allclose(eref, rel.ellipticity.sum(), atol=0.001)
